#!/bin/bash

#=================================================================
# This script is for on-prem cups printing server provisioning on 
# Redhat, CentOS, OL, and Amazon LINUX
#
# !! Note : It is NOT for Debian Linux
#=================================================================

readonly CUPS_DIR=/etc/cups
#readonly CFG_FILES=(cupsd.conf cups-browsed.conf)
readonly CFG_FILES=(cupsd.conf)
# the above CUPS config files is under CFGDIR
readonly CFGDIR=./

# check if internet is accessable, and write the info to /tmp/cups_ck_internet.log
function check_internet_access()
  if [[ "$(ping -c 1 8.8.8.8 | grep '100% packet loss' )" != "" ]]; then
    echo "Internet isn't present" >/tmp/cups_ck_internet.log
    echo "no"
else
    echo "Internet is present" >/tmp/cups_ck_internet.log
	 echo "yes"
fi


# mething should be called one time only
function one_time_cfg()
{
  #1. set SELinux to permissive
  sudo setenforce 0
  sudo sed -i "s@SELINUX=.*@SELINUX=disabled@g" /etc/selinux/config

  #2. update
  sudo yum update -y

  #3. handle firewall: enable to access port 631
  sudo firewall-cmd --permanent --add-port=631/tcp
  sudo systemctl reload firewalld

  #4. install CUPS
  sudo yum install cups.x86_64 cups-libs.x86_64 cups-client.x86_64 cups-filters.x86_64 -y
  
  #dummy printer, for testing only
  sudo yum install cups-pdf -y
  # install nc
  sudo yum install nc -y
  
  sudo systemctl enable cups
  #sudo systemctl enable cups-browsed
  sudo systemctl start cups
  #sudo systemctl start cups-browsed
 
  
  #5. copy cfg files  from ./
  for cf in "${CFG_FILES[@]}"
  do
    if [ -f $CUPS_DIR/$cf ]; then
      sudo mv $CUPS_DIR/$cf $CUPS_DIR/${cf}-orig
      sudo cp -p $CFGDIR/$cf $CUPS_DIR/
    fi
  done


  #6. restart cups services
  #sed -i "s@Listen localhost:631@Listen *:631@g" /etc/cups/cupsd.conf
  sudo systemctl restart cups
  #udo systemctl restart cups-browsed
}

#=================== main =================
# prompt to update the packages for the OS
echo "----------------------------------------------------"
echo " Going to update the packages before installing CUPS"
echo " It will take a few minutes"
echo "----------------------------------------------------"
echo ""
# sleep 5 seconds to show the above message to users
sleep 5

#check if the first time
if [ -f ~/cups-cfg.log ]; then
   date >>~/cups-cfg.log
   echo "Nothing to do " >> ~/cups-cfg.log
else
   internet_access=$(check_internet_access)
   if [ "$internet_access" = "yes" ]; then
      one_time_cfg
      date > ~/cups-cfg.log
      echo "First start; update and configure cups" >> ~/cups-cfg.log
   fi
fi
